#ifndef DEFINES_H
 #define DEFINES_H
 #include "defines.h"
#endif
#include "extra.h"

int des_setkey(char (*kn)[8], char *key);
int desinit(int mode);
int endes(char (*kn)[8], char *block);
int dedes(char (*kn)[8], char *block);
void desdone();
